@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: glibtop_machine.h,v 1.10 2004/06/06 22:07:44 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,31 +28,19 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-BEGIN_LIBGTOP_DECLS
-
-#if _IN_LIBGTOP
-
-static inline char *
-skip_token(const char *p)
-{
-    while (isspace(*p)) p++;
-    while (*p && !isspace(*p)) p++;
-    return (char *)p;
-}
-
-#endif
+G_BEGIN_DECLS
 
 typedef struct _glibtop_machine		glibtop_machine;
 
 struct _glibtop_machine
 {
-    pid_t	last_pid;
-    int	no_update;
-    int	fd_stat, fd_meminfo, fd_loadavg;
-    char	proc_stat [BUFSIZ], proc_statm [BUFSIZ];
-    char	proc_status [BUFSIZ];
+	pid_t	last_pid;
+	int	no_update;
+	int	fd_stat, fd_meminfo, fd_loadavg;
+	char	proc_stat [BUFSIZ], proc_statm [BUFSIZ];
+	char	proc_status [BUFSIZ];
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
